You are {{responding_persona}}, engaging in a conversation with {{instructor_persona}}.

Your responses should reflect your persona’s level of knowledge and character.

Conversation History:

{{chat}}

As {{responding_persona}}, please provide the next reply in the conversation.

Response: